summaryrefslogtreecommitdiffstats
path: root/kbackgammon/kbgboard.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kbackgammon/kbgboard.cpp')
-rw-r--r--kbackgammon/kbgboard.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kbackgammon/kbgboard.cpp b/kbackgammon/kbgboard.cpp
index 85c0a3a9..a065ec40 100644
--- a/kbackgammon/kbgboard.cpp
+++ b/kbackgammon/kbgboard.cpp
@@ -1166,7 +1166,7 @@ void KBgBoardBar::mouseDoubleClickEvent(TQMouseEvent *e)
{
TQRect r = cubeRect(cellID == BAR_THEM ? CUBE_UPPER : CUBE_LOWER, true);
if (board->canDouble(US) &&
- board->canDouble(THEM) && r.tqcontains(e->pos())) {
+ board->canDouble(THEM) && r.contains(e->pos())) {
if (board->getEditMode())
board->queryCube();
else
@@ -1332,7 +1332,7 @@ void KBgBoardHome::mouseDoubleClickEvent(TQMouseEvent * e)
US : THEM);
for (int i = 0; i < 2; ++i) {
TQRect r = diceRect(i, true);
- if (r.tqcontains(e->pos())) {
+ if (r.contains(e->pos())) {
if (board->getEditMode()) {
KBgBoardQDice *dlg = new KBgBoardQDice();
@@ -1356,7 +1356,7 @@ void KBgBoardHome::mouseDoubleClickEvent(TQMouseEvent * e)
if (board->canDouble(w) &&
!(board->canDouble(US) && board->canDouble(THEM))) {
TQRect r = cubeRect(w, true);
- if (r.tqcontains(e->pos()))
+ if (r.contains(e->pos()))
if (board->getEditMode())
board->queryCube();
else
@@ -1367,7 +1367,7 @@ void KBgBoardHome::mouseDoubleClickEvent(TQMouseEvent * e)
/*
* This function determines if a checker can be dropped on this field.
* It checks whether the field is already owned, empty or tqcontains
* only one opponents piece. Then the dice are checked.
*/
bool KBgBoardField::dropPossible(int fromCellID, int newColor)
@@ -1435,7 +1435,7 @@ bool KBgBoard::moveOffPossible() const
KBgBoardCell* KBgBoard::getCellByPos(const TQPoint& p) const
{
for (int i = 0; i < 30; ++i) {
- if (TQT_TQRECT_OBJECT(cells[i]->rect()).tqcontains(cells[i]->mapFromParent(p)))
+ if (TQT_TQRECT_OBJECT(cells[i]->rect()).contains(cells[i]->mapFromParent(p)))
return cells[i];
}
return NULL;
@@ -1367,7 +1367,7 @@ void KBgBoardHome::mouseDoubleClickEvent(TQMouseEvent * e)
/*
* This function determines if a checker can be dropped on this field.
- * It checks whether the field is already owned, empty or tqcontains
+ * It checks whether the field is already owned, empty or contains
* only one opponents piece. Then the dice are checked.
*/